==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/AuthenticatorSimple.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonSubTypes;
import com.fasterxml.jackson.annotation.JsonTypeInfo;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.AuthenticatorBase;
import com.okta.sdk.resource.model.AuthenticatorKeyEnum;
import com.okta.sdk.resource.model.AuthenticatorLinks;
import com.okta.sdk.resource.model.AuthenticatorType;
import com.okta.sdk.resource.model.LifecycleStatus;
import java.time.OffsetDateTime;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * AuthenticatorSimple
 */
@JsonPropertyOrder({})
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
@JsonTypeInfo(use = JsonTypeInfo.Id.NAME, include = JsonTypeInfo.As.EXISTING_PROPERTY, property = "key", visible = true, defaultImpl = AuthenticatorSimple.class)
@JsonSubTypes({ @JsonSubTypes.Type(value = AuthenticatorKeyCustomApp.class, name = "custom_app"),
        @JsonSubTypes.Type(value = AuthenticatorKeyDuo.class, name = "duo"),
        @JsonSubTypes.Type(value = AuthenticatorKeyExternalIdp.class, name = "external_idp"),
        @JsonSubTypes.Type(value = AuthenticatorKeyGoogleOtp.class, name = "google_otp"),
        @JsonSubTypes.Type(value = AuthenticatorKeyEmail.class, name = "okta_email"),
        @JsonSubTypes.Type(value = AuthenticatorKeyPassword.class, name = "okta_password"),
        @JsonSubTypes.Type(value = AuthenticatorKeyOktaVerify.class, name = "okta_verify"),
        @JsonSubTypes.Type(value = AuthenticatorKeyOnprem.class, name = "onprem_mfa"),
        @JsonSubTypes.Type(value = AuthenticatorKeyPhone.class, name = "phone_number"),
        @JsonSubTypes.Type(value = AuthenticatorKeySecurityKey.class, name = "security_key"),
        @JsonSubTypes.Type(value = AuthenticatorKeySecurityQuestion.class, name = "security_question"),
        @JsonSubTypes.Type(value = AuthenticatorKeySmartCard.class, name = "smart_card_idp"),
        @JsonSubTypes.Type(value = AuthenticatorKeySymantecVip.class, name = "symantec_vip"),
        @JsonSubTypes.Type(value = AuthenticatorKeyWebauthn.class, name = "webauthn"),
        @JsonSubTypes.Type(value = AuthenticatorKeyYubikey.class, name = "yubikey_token"), })

public class AuthenticatorSimple extends AuthenticatorBase implements Serializable {

    private static final long serialVersionUID = 1L;

    public AuthenticatorSimple() {
    }

    /*
     * @JsonCreator public AuthenticatorSimple(
     *
     * @JsonProperty(JSON_PROPERTY_CREATED) OffsetDateTime created,
     *
     * @JsonProperty(JSON_PROPERTY_ID) String id,
     *
     * @JsonProperty(JSON_PROPERTY_LAST_UPDATED) OffsetDateTime lastUpdated ) { this(); this.created = created; this.id
     * = id; this.lastUpdated = lastUpdated; }
     */

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }

        return super.equals(o);
    }

    @Override
    public int hashCode() {
        return Objects.hash(super.hashCode());
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class AuthenticatorSimple {\n");
        sb.append("    ").append(toIndentedString(super.toString())).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-21.0.0-sources.jar: com/okta/sdk/resource/model/AuthenticatorSimple.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonSubTypes;
import com.fasterxml.jackson.annotation.JsonTypeInfo;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.AuthenticatorBase;
import com.okta.sdk.resource.model.AuthenticatorKeyEnum;
import com.okta.sdk.resource.model.AuthenticatorLinks;
import com.okta.sdk.resource.model.AuthenticatorType;
import com.okta.sdk.resource.model.LifecycleStatus;
import java.time.OffsetDateTime;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * AuthenticatorSimple
 */
@JsonPropertyOrder({})
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-02-24T22:29:38.763116-06:00[America/Chicago]", comments = "Generator version: 7.11.0")
@JsonTypeInfo(use = JsonTypeInfo.Id.NAME, include = JsonTypeInfo.As.EXISTING_PROPERTY, property = "key", visible = true, defaultImpl = AuthenticatorSimple.class)
@JsonSubTypes({ @JsonSubTypes.Type(value = AuthenticatorKeyCustomApp.class, name = "custom_app"),
        @JsonSubTypes.Type(value = AuthenticatorKeyDuo.class, name = "duo"),
        @JsonSubTypes.Type(value = AuthenticatorKeyExternalIdp.class, name = "external_idp"),
        @JsonSubTypes.Type(value = AuthenticatorKeyGoogleOtp.class, name = "google_otp"),
        @JsonSubTypes.Type(value = AuthenticatorKeyEmail.class, name = "okta_email"),
        @JsonSubTypes.Type(value = AuthenticatorKeyPassword.class, name = "okta_password"),
        @JsonSubTypes.Type(value = AuthenticatorKeyOktaVerify.class, name = "okta_verify"),
        @JsonSubTypes.Type(value = AuthenticatorKeyOnprem.class, name = "onprem_mfa"),
        @JsonSubTypes.Type(value = AuthenticatorKeyPhone.class, name = "phone_number"),
        @JsonSubTypes.Type(value = AuthenticatorKeySecurityKey.class, name = "security_key"),
        @JsonSubTypes.Type(value = AuthenticatorKeySecurityQuestion.class, name = "security_question"),
        @JsonSubTypes.Type(value = AuthenticatorKeySmartCard.class, name = "smart_card_idp"),
        @JsonSubTypes.Type(value = AuthenticatorKeySymantecVip.class, name = "symantec_vip"),
        @JsonSubTypes.Type(value = AuthenticatorKeyWebauthn.class, name = "webauthn"),
        @JsonSubTypes.Type(value = AuthenticatorKeyYubikey.class, name = "yubikey_token"), })

public class AuthenticatorSimple extends AuthenticatorBase implements Serializable {

    private static final long serialVersionUID = 1L;

    public AuthenticatorSimple() {
    }

    /*
     * @JsonCreator public AuthenticatorSimple(
     *
     * @JsonProperty(JSON_PROPERTY_CREATED) OffsetDateTime created,
     *
     * @JsonProperty(JSON_PROPERTY_ID) String id,
     *
     * @JsonProperty(JSON_PROPERTY_LAST_UPDATED) OffsetDateTime lastUpdated ) { this(); this.created = created; this.id
     * = id; this.lastUpdated = lastUpdated; }
     */

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }

        return super.equals(o);
    }

    @Override
    public int hashCode() {
        return Objects.hash(super.hashCode());
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class AuthenticatorSimple {\n");
        sb.append("    ").append(toIndentedString(super.toString())).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
